@@ -107,33 +107,32 @@ CLF_PATH_PATTERN_REPLACEMENT = {
 
 BASE_CFGS = {
     'Bucket': {
-        'Enabled': 'None',
-        'Create': 'None',
+        'Create': 'no',
         'AccountsRead': {
-            'dev': 'None',
-            'stg': 'None',
-            'prd': 'None',
+            'dev': 'none',
+            'stg': 'none',
+            'prd': 'none',
         },
         'AccountsWrite': {
-            'dev': 'None',
-            'stg': 'None',
-            'prd': 'None',
+            'dev': 'none',
+            'stg': 'none',
+            'prd': 'none',
         },
-        'Cors': 'None',
+        'Cors': 'no',
         'CloudFrontOriginAccessIdentityExtra': {
-            'Dev': 'None',
-            'Stg': 'None',
-            'Prd': 'None',
+            'Dev': 'none',
+            'Stg': 'none',
+            'Prd': 'none',
         },
         'PolicyStatementReplica': {
             'Resource': {},
-            'Principal': 'None',
+            'Principal': 'none',
         },
         'Replication': {
-            'Enabled': 'None',
+            'Enabled': 'no',
             'ConfigurationRules': {},
         },
-        'Versioning': 'None',
+        'Versioning': 'Disabled',
     },
     'CloudFrontCacheBehaviors': {
         'Compress': True,
@@ -143,11 +142,11 @@ BASE_CFGS = {
         },
         'ViewerProtocolPolicy': 'redirect-to-https'
     },
-    'CloudFrontOrigins': 'IBOXBASE',
-    'DBInstance': 'IBOXBASE',
-    'ScheduledAction': 'IBOXBASE',
-    'ContainerDefinitions': 'IBOXBASE',
-    'AllowedIp': 'IBOXBASE',
+    'CloudFrontOrigins': 'IBOX_BASE',
+    'DBInstance': 'IBOX_BASE',
+    'ScheduledAction': 'IBOX_BASE',
+    'ContainerDefinitions': 'IBOX_BASE',
+    'AllowedIp': 'IBOX_BASE',
 }
 
 INSTANCE_LIST = [
@@ -201,6 +200,10 @@ CFG_TO_FUNC = {
                   'func': 'CFM_Conditions'},
     'Mapping': {'module': 'cloudformation',
                 'func': 'CFM_Mappings'},
+    # SecurityGroups need to stay here because it populate a cfg value
+    # [cfg.SecurityGroupsImport] used later by other keys/modules
+    'SecurityGroups': {'module': 'securitygroup',
+                       'func': 'SG_SecurityGroups'},
     'AutoScalingGroup': {'module': 'autoscaling',
                          'func': 'AS_Autoscaling'},
     'ScalableTarget': {'module': 'autoscaling',
@@ -217,8 +220,13 @@ CFG_TO_FUNC = {
                       'func': 'CD_Applications'},
     'Repository': {'module': 'ecr',
                    'func': 'ECR_Repositories'},
-    'Cluster': {'module': 'ecs',
-                'func': 'ECS_Cluster'},
+    'ECSCluster': {'module': 'ecs',
+                   'func': 'ECS_Cluster'},
+    'ECSCapacityProvider': {'module': 'ecs',
+                            'func': 'ECS_CapacityProvider'},
+    'ECSClusterCapacityProviderAssociations': {
+        'module': 'ecs',
+        'func': 'ECS_ClusterCapacityProviderAssociations'},
     'Service': {'module': 'ecs',
                 'func': 'ECS_Service'},
     'ApiGatewayAccount': {'module': 'apigateway',
@@ -277,8 +285,8 @@ CFG_TO_FUNC = {
                             'func': 'LB_ElasticLoadBalancing'},
     'Alarm': {'module': 'cloudwatch',
               'func': 'CW_Alarms'},
-    'CloudFront': {'module': 'cloudfront',
-                   'func': 'CF_CloudFront'},
+    'CloudFrontDistribution': {'module': 'cloudfront',
+                               'func': 'CF_CloudFront'},
     'CloudFrontCachePolicy': {'module': 'cloudfront',
                               'func': 'CF_CachePolicy'},
     'CloudFrontOriginRequestPolicy': {'module': 'cloudfront',
