@@ -7,7 +7,7 @@ from .shared import (Parameter, get_endvalue, get_expvalue, get_subvalue,
 
 def CRM_Certificate(key):
     for n, v in getattr(cfg, key).items():
-        if not v['IBOXENABLED']:
+        if not v['IBOX_ENABLED']:
             continue
         # resources
         resname = f'{key}{n}'
@@ -28,7 +28,7 @@ def CRM_Certificate(key):
 
 
 def CRM_CertificateEC2(key):
-    if cfg.ListenerLoadBalancerHttpsPort != 'None':
+    if cfg.ListenerLoadBalancerHttpsPort != 'none':
         CRM_Certificate(key)
 
 
