@@ -41,13 +41,13 @@ class ECSContainerDefinition(ecs.ContainerDefinition):
                 ['EcrAccount', f'{name}RepoName']
             )
         # use the same EnvApp version for all containers
-        elif cfg.RepoName != 'None':
+        elif cfg.RepoName:
             self.Image = get_subvalue(
                 '${1M}.dkr.ecr.${AWS::Region}.amazonaws.com/${2M}:'
                 '${EnvApp1Version}',
                 ['EcrAccount', 'RepoName']
             )
-        elif cfg.Image != 'None':
+        elif cfg.Image:
             self.Image = get_endvalue('Image')
 
         if 'Name' in key:
@@ -86,7 +86,7 @@ def ECS_ContainerDefinition():
             o_EnvAppOut.Value = Ref(nameenvapp)
 
             # and use different output for RepoName
-            if cfg.RepoName != 'None':
+            if cfg.RepoName:
                 if 'RepoName' in v:
                     o_Repo = Output(f'{name}RepoName')
                     o_Repo.Value = get_endvalue(f'{name}RepoName')
@@ -162,7 +162,7 @@ def ECS_Service(key):
     add_obj(R_SG)
 
     for n, v in getattr(cfg, key).items():
-        if not v['IBOXENABLED']:
+        if not v['IBOX_ENABLED']:
             continue
         mapname = f'{key}{n}'
 
@@ -203,9 +203,30 @@ def ECS_Service(key):
 
 
 def ECS_Cluster(key):
-    # Resources
-    R_Cluster = ecs.Cluster('Cluster')
+    for n, v in getattr(cfg, key).items():
+        mapname = f'{key}{n}'
+        r_Cluster = ecs.Cluster(mapname)
+        auto_get_props(r_Cluster)
 
-    add_obj([
-        R_Cluster,
-    ])
+        add_obj([
+            r_Cluster,
+        ])
+
+
+def ECS_CapacityProvider(key):
+    for n, v in getattr(cfg, key).items():
+        mapname = f'{key}{n}'
+        r_CapacityProvider = ecs.CapacityProvider(mapname)
+        auto_get_props(r_CapacityProvider)
+
+        add_obj(r_CapacityProvider)
+
+
+def ECS_ClusterCapacityProviderAssociations(key):
+    for n, v in getattr(cfg, key).items():
+        mapname = f'{key}{n}'
+        r_CapacityProviderAss = ecs.ClusterCapacityProviderAssociations(
+            mapname)
+        auto_get_props(r_CapacityProviderAss)
+
+        add_obj(r_CapacityProviderAss)
